pub struct RequestId(pub u64);Expand description
Unique ID for a request from the kernel
The FUSE kernel driver assigns a unique id to every concurrent request. This allows to distinguish between multiple concurrent requests. The unique id of a request may be reused in later requests after it has completed.
This can be retrieve for any request using Request::unique. The kernel
will send an Interrupt request to cancel requests in progress. It’s
important to handle this for any requests that may block indefinitely, like
SetLkW.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Ord for RequestId
impl Ord for RequestId
Sourceimpl PartialOrd for RequestId
impl PartialOrd for RequestId
impl Copy for RequestId
impl Eq for RequestId
impl StructuralPartialEq for RequestId